@@ -24,7 +24,8 @@ class Customer(QuickbooksManagedObject):
         "WebAddr": WebAddress,
         "DefaultTaxCodeRef": Ref,
         "SalesTermRef": Ref,
-        "PaymentMethodRef": Ref
+        "PaymentMethodRef": Ref,
+        "CurrencyRef": Ref
     }
 
     qbo_object_name = "Customer"
@@ -63,3 +64,12 @@ class Customer(QuickbooksManagedObject):
 
     def __unicode__(self):
         return self.DisplayName
+
+    def to_ref(self):
+        ref = Ref()
+
+        ref.name = self.DisplayName
+        ref.type = self.qbo_object_name
+        ref.value = self.Id
+
+        return ref
