@@ -2,15 +2,15 @@ from base import QuickbooksBaseObject, Ref, LinkedTxn, QuickbooksManagedObject
 
 
 class PaymentLine(QuickbooksBaseObject):
-    class_dict = {
+    list_dict = {
         "LinkedTxn": LinkedTxn,
     }
 
-    list_dict = {}
-
     def __init__(self):
         super(PaymentLine, self).__init__()
         self.Amount = 0
+        self.LineNum = 0
+        self.Description = ""
 
 
 class Payment(QuickbooksManagedObject):
